import json
import os

class js:
    def write(data, filename):
        data = json.dumps(data)
        data = json.loads(str(data))
        with open(filename, 'w', encoding='utf-8') as file:
            json.dump(data, file, indent=4)

    def read(filename):
        with open(filename, 'r', encoding='utf-8') as file:
            return json.load(file)


import setuptools

setuptools.setup(
	name='systemJSON',
	version='0.1',
	author='DanXvo',
	author_email='coldreality@mail.ru',
	description='is lib for json',
	packages=['systemJSON'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)